@@ -16,12 +16,12 @@ __copyright__ = "2017 Rodrigo E. Principe"
 try:
     from . import tools, bitreader, cloud_mask, expressions, decision_tree,\
                   filters, indices, batch, algorithms, composite,\
-                  manager, utils, collection, oauth, visualization, \
-                  classification
+                  manager, utils, collection, oauth, visualization
     from .tools import array, date, dictionary, ee_list, featurecollection, \
                        geometry, image, imagecollection, number, string
     from .ui import eprint
     from .batch import Export, Import, Convert, Download
     from .oauth import Initialize
+    from .utils import evaluate
 except ImportError:
     pass
