@@ -2,4 +2,4 @@
 
 from . import collection, date, dictionary, ee_list, featurecollection, \
               geometry, image, imagecollection, number, string, array, \
-              computedobject, element
\ No newline at end of file
+              computedobject, element, feature
\ No newline at end of file
