@@ -165,7 +165,6 @@ def fillWithLast(collection, reverse=False, date_property='system:time_start'):
 
         def true():
             last = ee.Image(collect.get(-1))
-            idate = ee.Number(i.get(date_property))
             blended = i.unmask().where(i.mask().Not(), last)
             return collect.add(blended)
 
@@ -1003,3 +1002,37 @@ def maskedSize(collection):
     masksum = mask.sum()
     totalsum = total.sum()
     return masksum.divide(totalsum).multiply(100).toInt()
+
+
+def area_under_curve(collection, band, x_property=None, name='area_under'):
+    """ Compute the area under the curve taking the x axis from an image
+    property. If not specified, it'll use `system:time_start` """
+    x_property = x_property or "system:time_start"
+    max_x = collection.aggregate_max(x_property)
+    min_x = collection.aggregate_min(x_property)
+    total_lapsed = ee.Number(max_x).subtract(ee.Number(min_x))
+
+    def cummulative(image, cumm):
+        cumm = ee.List(cumm)
+
+        def true(i, c):
+            c = ee.List(c)
+            last = ee.Image(c.get(-1))
+            lapsed = ee.Number(image.get(x_property)).subtract(
+                ee.Number(last.get(x_property)))
+            lapsed_percent = lapsed.divide(total_lapsed)
+            rise = i.select(band).subtract(last.select(band)).divide(2)
+            toadd = i.select(band).add(rise).multiply(lapsed_percent).rename(
+                name).toFloat()
+            return c.add(i.addBands(toadd))
+
+        def false(i, c):
+            toadd = i.addBands(ee.Image(0).rename(name).toFloat())
+            return c.add(toadd)
+
+        return ee.List(ee.Algorithms.If(cumm.size(), true(image, cumm),
+                                        false(image, cumm)))
+
+    final = ee.List(collection.iterate(cummulative, ee.List([])))
+    final_ic = ee.ImageCollection.fromImages(final).select(name)
+    return ee.Image(final_ic.reduce(ee.Reducer.sum()))
